import sys
from PyQt5.QtWidgets import (
    QApplication, QWidget, QLabel, QLineEdit, QPushButton, QVBoxLayout, QHBoxLayout, QDialog,
    QMessageBox, QFormLayout
)

import api
import os
import threading

api.initialization()
# 函数来保存凭据到文件
def save_credentials(username, password):
    with open('credentials.txt', 'w') as f:
        f.write(username + '\n')
        f.write(password)

# 函数来读取凭据文件
def load_credentials():
    if os.path.exists('credentials.txt'):
        with open('credentials.txt', 'r') as f:
            username = f.readline().strip()
            password = f.readline().strip()
            return username, password
    return None, None

def perform_recharge(account, card):
    # 这里替换为你的API充值函数，并确保account和card参数正确传递
    result = api.recharge(account, card)
    if result.status_code == 200:
        QMessageBox.information(window, '充值成功', '充值金额：' + str(amount) + '元')
    else:
        QMessageBox.warning(window, '充值失败', '错误信息：' + result.text)

def handle_login():
    username = username_input.text()
    password = password_input.text()
    result = api.login(username, password)
    status = result.split('|')
    if status[0] == "ok":
        QMessageBox.information(window, '登录成功', '到期时间：'+status[1])
        window.hide()  # 隐藏登录窗口
        save_credentials(username, password)  # 保存凭据

  
    else:
        QMessageBox.information(window, '登录失败', result)
    

def handle_register():
    register_dialog = QDialog(window)
    register_dialog.setWindowTitle('注册')

    username_reg_label = QLabel('账号:')
    username_reg_input = QLineEdit()
    password_reg_label = QLabel('密码:')
    password_reg_input = QLineEdit()
    password_reg_input.setEchoMode(QLineEdit.Password)
    password_confirm_label = QLabel('确认密码:')
    password_confirm_input = QLineEdit()
    password_confirm_input.setEchoMode(QLineEdit.Password)

    register_buttons = QPushButton('注册')
    register_buttons.clicked.connect(lambda: perform_registration(
        username_reg_input.text(),
        password_reg_input.text(),
        password_confirm_input.text(),
        register_dialog,
    ))




   

    form_layout = QFormLayout()
    form_layout.addRow(username_reg_label, username_reg_input)
    form_layout.addRow(password_reg_label, password_reg_input)
    form_layout.addRow(password_confirm_label, password_confirm_input)
    form_layout.addWidget(register_buttons)
    form_layout.addWidget(register_pay)

    register_dialog.setLayout(form_layout)
    register_dialog.exec_()


def handle_pay():
    register_dialog = QDialog(window)
    register_dialog.setWindowTitle('充值')

    username_reg_label = QLabel('账号:')
    username_reg_input = QLineEdit()
    password_reg_label = QLabel('卡号:')
    password_reg_input = QLineEdit()


    register_pay = QPushButton('充值')
    register_pay.clicked.connect(lambda: pay(
        username_reg_input.text(),
        password_reg_input.text(), 
    ))

   

    form_layout = QFormLayout()
    form_layout.addRow(username_reg_label, username_reg_input)
    form_layout.addRow(password_reg_label, password_reg_input)
    form_layout.addWidget(register_pay)
    form_layout.addWidget(register_pay)

    register_dialog.setLayout(form_layout)
    register_dialog.exec_()


def perform_registration(username, password, password_confirm,dialog):
    if password != password_confirm:
        QMessageBox.warning(dialog, '错误', '两次输入的密码不一致！')
        return

    result = api.register(username, password)
    QMessageBox.information(dialog, '注册状态', result)
    dialog.accept()
 
def pay(username, password):
    # 这里替换为你的注册函数，并确保username和password参数正确传递
    result = api.pays(username, password)
    if result == "ok":
        QMessageBox.information(window, '充值成功', '用户名：' + username)
    else:
        QMessageBox.warning(window, '充值失败', '错误信息：' + result.text)

app = QApplication(sys.argv)


loaded_username, decrypted_password = load_credentials()
window = QWidget()
window.setWindowTitle('登录')

username_label = QLabel('账号:')
username_input = QLineEdit(loaded_username)

password_label = QLabel('密码:')
password_input = QLineEdit(decrypted_password)
password_input.setEchoMode(QLineEdit.Password)

login_button = QPushButton('登录')
login_button.clicked.connect(handle_login)

register_buttons = QPushButton('没有账号？注册')
register_buttons.clicked.connect(handle_register)

register_pay = QPushButton('充值')
register_pay.clicked.connect(handle_pay)

purchase_card_label = QLabel('<a href="'+api.pay("购卡地址") +'">点我购卡</a>')
purchase_card_label.setOpenExternalLinks(True)


announcement_text = api.pay("公告")
announcement_label = QLabel(announcement_text)
announcement_label.setWordWrap(True)  # 允许文本换行
announcement_label.setStyleSheet("background-color: white;")
# 调整公告栏的高度（可选）
announcement_label.setMinimumHeight(50)  # 设置公告栏的最小高度为50像素




layout = QVBoxLayout()
layout.addWidget(username_label)
layout.addWidget(username_input)
layout.addWidget(password_label)
layout.addWidget(password_input)
layout.addWidget(login_button)
layout.addWidget(register_buttons)
layout.addWidget(register_pay)
# 在布局中添加公告栏，可以将其放置在窗口顶部或其他您希望的位置
layout.insertWidget(0, announcement_label)  # 第一个参数是索引，0意味着将它插入到最顶部

links_layout = QHBoxLayout()
links_layout.addWidget(purchase_card_label)

layout.addLayout(links_layout)
window.setLayout(layout)
window.show()

sys.exit(app.exec_())
